@@ -19,7 +19,7 @@
 #include "filterkmail_maildir.h"
 
 #include <KLocalizedString>
-#include <qfiledialog.h>
+#include <QFileDialog>
 
 using namespace MailImporter;
 
