@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>                      */
 
 #ifndef MAILIMPORTER_FILTER_THEBAT_H
 #define MAILIMPORTER_FILTER_THEBAT_H
@@ -31,7 +31,7 @@ class MAILIMPORTER_EXPORT FilterTheBat : public Filter
 {
 public:
     FilterTheBat();
-    ~FilterTheBat();
+    ~FilterTheBat() override;
 
     void import() override;
     void importMails(const QString &maildir);
